@@ -718,8 +718,12 @@ class Builder(Update):
                 # self.emerge_cache.drop_cache("Emerge error")
                 self._display_install_package(emerge, emergelike=True)
                 self._display_error(emerge.prepare_error)
-                raise
-            self._startEmerging(emerge, _("Fetching..."))
+                return False
+            try:
+                self._startEmerging(emerge, _("Fetching..."))
+            except Exception as e:
+                self.printERROR(_("Emerge error was occurred while fetching packages"))
+                return False
         return True
 
     def depclean(self, without_bdeps=False):
